@@ -1482,7 +1482,7 @@ def create_app():
     
     @app.post("/generate-image-sync")
     async def generate_image_sync(request: ImageGenerationSyncRequest):
-        """同步图片生成接口 - 阻塞等待直到任务完成"""
+        """同步图片生成接口 - 阻塞直到完成"""
         try:
             # 构建配置
             config = {}
@@ -1497,13 +1497,26 @@ def create_app():
                 if request.access_key and request.secret_key:
                     config["access_key"] = request.access_key
                     config["secret_key"] = request.secret_key
-                else:
-                    raise HTTPException(
-                        status_code=400, 
-                        detail="即梦AI需要提供access_key和secret_key参数"
-                    )
+                elif not config:
+                    # 如果没有提供运行时密钥，尝试从环境变量获取
+                    import os
+                    env_access_key = os.getenv("JIMENG_ACCESS_KEY")
+                    env_secret_key = os.getenv("JIMENG_SECRET_KEY")
+                    if env_access_key and env_secret_key:
+                        config["access_key"] = env_access_key
+                        config["secret_key"] = env_secret_key
+                    else:
+                        raise HTTPException(
+                            status_code=400, 
+                            detail="即梦AI需要提供access_key和secret_key参数或设置环境变量"
+                        )
                 if request.model:
                     config["model"] = request.model
+            else:
+                raise HTTPException(
+                    status_code=400,
+                    detail=f"同步模式暂不支持提供商: {request.provider}"
+                )
             
             # 获取适配器
             adapter = model_manager.get_adapter(request.provider, config if config else None)
@@ -1516,143 +1529,136 @@ def create_app():
                 )
             
             # 构建生成参数
-            params = {"prompt": request.prompt}
+            kwargs = {}
             if request.size:
-                params["size"] = request.size
-            if request.width:
-                params["width"] = request.width
-            if request.height:
-                params["height"] = request.height
+                kwargs["size"] = request.size
             if request.n:
-                params["n"] = request.n
-            if request.scale:
-                params["scale"] = request.scale
+                kwargs["n"] = request.n
+            if request.width:
+                kwargs["width"] = request.width
+            if request.height:
+                kwargs["height"] = request.height
+            if request.scale is not None:
+                kwargs["scale"] = request.scale
             if request.force_single is not None:
-                params["force_single"] = request.force_single
+                kwargs["force_single"] = request.force_single
             if request.image_urls:
-                params["image_urls"] = request.image_urls
+                kwargs["image_urls"] = request.image_urls
+            
+            print(f"🕐 **开始同步图片生成** - 提供商: {request.provider}, 超时: {request.timeout}秒")
             
             # 提交图片生成任务
-            result = await adapter.generate_image(**params)
+            result = await adapter.generate_image(request.prompt, **kwargs)
             
-            # 如果直接返回了图片URL（某些适配器可能支持同步）
-            if isinstance(result, dict) and "images" in result:
-                return ImageGenerationResponse(
-                    status="completed",
-                    images=result["images"],
-                    provider=request.provider,
-                    model=request.model or adapter.model,
-                    message="图片生成完成"
-                )
-            
-            # 获取任务ID
+            # 提取task_id
             task_id = None
-            if isinstance(result, dict):
-                task_id = result.get("task_id") or result.get("id")
+            if request.provider == "tongyi_wanxiang":
+                if "output" in result and "task_id" in result["output"]:
+                    task_id = result["output"]["task_id"]
+            elif request.provider == "jimeng":
+                if "data" in result and "task_id" in result["data"]:
+                    task_id = result["data"]["task_id"]
             
             if not task_id:
-                raise HTTPException(
-                    status_code=500, 
-                    detail="无法获取任务ID"
-                )
+                raise HTTPException(status_code=500, detail="无法获取任务ID")
             
-            # 轮询等待任务完成
-            import asyncio
-            timeout = request.timeout or 300
-            poll_interval = request.poll_interval or 3
-            start_time = asyncio.get_event_loop().time()
+            print(f"📋 **任务已提交** - Task ID: {task_id}")
             
-            while True:
-                # 检查超时
-                if asyncio.get_event_loop().time() - start_time > timeout:
-                    return ImageGenerationResponse(
-                        task_id=task_id,
-                        status="timeout",
-                        provider=request.provider,
-                        model=request.model or adapter.model,
-                        message=f"任务超时（{timeout}秒）"
-                    )
+            # 轮询等待结果
+            import time
+            start_time = time.time()
+            poll_count = 0
+            
+            while time.time() - start_time < request.timeout:
+                poll_count += 1
+                print(f"🔄 **轮询检查 #{poll_count}** - 等待 {request.poll_interval} 秒...")
                 
-                # 查询任务状态
-                status_result = await adapter.get_task_status(task_id)
+                await asyncio.sleep(request.poll_interval)
                 
-                # 解析状态
-                if request.provider == "tongyi_wanxiang":
-                    if "output" in status_result:
-                        output = status_result["output"]
-                        task_status = output.get("task_status")
-                        
-                        if task_status == "SUCCEEDED":
-                            # 提取图片URL
-                            images = []
-                            if "results" in output:
-                                for result_item in output["results"]:
-                                    if "url" in result_item:
-                                        images.append(result_item["url"])
+                try:
+                    # 查询任务状态
+                    status_result = await adapter.get_task_status(task_id)
+                    
+                    if request.provider == "tongyi_wanxiang":
+                        if "output" in status_result:
+                            output = status_result["output"]
+                            task_status = output.get("task_status")
                             
-                            return ImageGenerationResponse(
-                                task_id=task_id,
-                                status="completed",
-                                images=images,
-                                provider=request.provider,
-                                model=request.model or adapter.model,
-                                message="图片生成完成"
-                            )
-                        elif task_status == "FAILED":
-                            error_msg = output.get("message", "未知错误")
-                            return ImageGenerationResponse(
-                                task_id=task_id,
-                                status="failed",
-                                provider=request.provider,
-                                model=request.model or adapter.model,
-                                message=f"任务失败: {error_msg}"
-                            )
-                
-                elif request.provider == "jimeng":
-                    if "data" in status_result:
-                        data = status_result["data"]
-                        status = data.get("status")
-                        
-                        if status == "done" and status_result.get("code") == 10000:
-                            # 提取图片URL
-                            images = data.get("image_urls", [])
+                            if task_status == "SUCCEEDED":
+                                # 提取图片URL
+                                images = []
+                                if "results" in output:
+                                    for result_item in output["results"]:
+                                        if "url" in result_item:
+                                            images.append(result_item["url"])
+                                
+                                print(f"✅ **任务完成** - 生成 {len(images)} 张图片")
+                                return ImageGenerationResponse(
+                                    task_id=task_id,
+                                    status="completed",
+                                    images=images,
+                                    provider=request.provider,
+                                    model=request.model or adapter.model,
+                                    message=f"同步任务完成，耗时 {int(time.time() - start_time)} 秒"
+                                )
+                            elif task_status == "FAILED":
+                                error_msg = output.get("message", "未知错误")
+                                print(f"❌ **任务失败** - {error_msg}")
+                                return ImageGenerationResponse(
+                                    task_id=task_id,
+                                    status="failed",
+                                    provider=request.provider,
+                                    model=request.model or adapter.model,
+                                    message=f"任务失败: {error_msg}"
+                                )
+                            else:
+                                print(f"⏳ **任务进行中** - 状态: {task_status}")
+                    
+                    elif request.provider == "jimeng":
+                        if "data" in status_result:
+                            data = status_result["data"]
+                            status = data.get("status")
                             
-                            return ImageGenerationResponse(
-                                task_id=task_id,
-                                status="completed",
-                                images=images,
-                                provider=request.provider,
-                                model=request.model or adapter.model,
-                                message="图片生成完成"
-                            )
-                        elif status == "done":
-                            error_msg = status_result.get("message", "未知错误")
-                            return ImageGenerationResponse(
-                                task_id=task_id,
-                                status="failed",
-                                provider=request.provider,
-                                model=request.model or adapter.model,
-                                message=f"任务失败: {error_msg}"
-                            )
-                        elif status == "not_found":
-                            return ImageGenerationResponse(
-                                task_id=task_id,
-                                status="not_found",
-                                provider=request.provider,
-                                model=request.model or adapter.model,
-                                message="任务未找到"
-                            )
-                        elif status == "expired":
-                            return ImageGenerationResponse(
-                                task_id=task_id,
-                                status="expired",
-                                provider=request.provider,
-                                model=request.model or adapter.model,
-                                message="任务已过期"
-                            )
+                            if status == "done" and status_result.get("code") == 10000:
+                                # 提取图片URL
+                                images = data.get("image_urls", [])
+                                
+                                print(f"✅ **任务完成** - 生成 {len(images)} 张图片")
+                                return ImageGenerationResponse(
+                                    task_id=task_id,
+                                    status="completed",
+                                    images=images,
+                                    provider=request.provider,
+                                    model=request.model or adapter.model,
+                                    message=f"同步任务完成，耗时 {int(time.time() - start_time)} 秒"
+                                )
+                            elif status == "done":
+                                error_msg = status_result.get("message", "未知错误")
+                                print(f"❌ **任务失败** - {error_msg}")
+                                return ImageGenerationResponse(
+                                    task_id=task_id,
+                                    status="failed",
+                                    provider=request.provider,
+                                    model=request.model or adapter.model,
+                                    message=f"任务失败: {error_msg}"
+                                )
+                            else:
+                                print(f"⏳ **任务进行中** - 状态: {status}")
                 
-                # 等待下次轮询
-                await asyncio.sleep(poll_interval)
+                except Exception as poll_error:
+                    print(f"⚠️ **轮询错误** - {poll_error}")
+                    continue
+            
+            # 超时返回
+            elapsed = int(time.time() - start_time)
+            print(f"⏰ **任务超时** - 已等待 {elapsed} 秒")
+            return ImageGenerationResponse(
+                task_id=task_id,
+                status="timeout",
+                provider=request.provider,
+                model=request.model or adapter.model,
+                message=f"任务超时（{elapsed}秒），请稍后使用task_id查询结果"
+            )
                 
         except ConfigurationError as e:
             raise HTTPException(status_code=400, detail=str(e))
